==> meutils-2024.9.23.15.14.4.tar.gz: meutils-2024.9.23.15.14.4/meutils/db/redis_db.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : redis
# @Time         : 2024/3/26 11:21
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
from meutils.pipe import *

import os
from redis import Redis
from redis.asyncio import Redis as AsyncRedis

if REDIS_URL := os.getenv("REDIS_URL"):
    redis_client = Redis.from_url(REDIS_URL)
    redis_aclient = AsyncRedis.from_url(REDIS_URL)
else:
    redis_client = Redis()  # decode_responses=True
    redis_aclient = AsyncRedis()

if __name__ == '__main__':
    from meutils.pipe import *

    # print(arun(redis_aclient.get("")))
    # print(redis_client.lrange("https://api.moonshot.cn/v1",0, -1))

    # print(redis_client.lrange("https://api.deepseek.com/v1",0, -1))
    # print(redis_client.exists("https://api.deepseek.com/v1"))

    # print(type(redis_aclient.get("test")))

    # print(redis_client.delete("https://api.deepseek.com/v1"))
    feishu_url = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=79272d"
    feishu_url = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=EYgZ8c"

    with timer():
        print(feishu_url in redis_client)

    with timer():
        redis_client.exists(feishu_url)
    with timer():
        print(redis_client.llen(feishu_url))

    print(redis_client.lpop('xx21212'))

    #
    # print(redis_client.type(feishu))
    # _ = redis_client.lrange(feishu, 0, -1)
    # print(len(eval(_)))

==> meutils-2024.9.28.8.7.43.tar.gz: meutils-2024.9.28.8.7.43/meutils/db/redis_db.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : redis
# @Time         : 2024/3/26 11:21
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
# from meutils.pipe import *

import os
from redis import Redis
from redis.asyncio import Redis as AsyncRedis

kwargs = {
    "retry_on_timeout": True
}
if REDIS_URL := os.getenv("REDIS_URL"):
    redis_client = Redis.from_url(REDIS_URL, **kwargs)
    redis_aclient = AsyncRedis.from_url(REDIS_URL, **kwargs)
else:
    redis_client = Redis(**kwargs)  # decode_responses=True
    redis_aclient = AsyncRedis(**kwargs)

if __name__ == '__main__':
    from meutils.pipe import *

    # print(arun(redis_aclient.get("")))
    # print(redis_client.lrange("https://api.moonshot.cn/v1",0, -1))

    # print(redis_client.lrange("https://api.deepseek.com/v1",0, -1))
    # print(redis_client.exists("https://api.deepseek.com/v1"))

    # print(type(redis_aclient.get("test")))

    # print(redis_client.delete("https://api.deepseek.com/v1"))
    feishu_url = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=79272d"
    feishu_url = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=EYgZ8c"

    with timer():
        print(feishu_url in redis_client)

    with timer():
        redis_client.exists(feishu_url)
    with timer():
        print(redis_client.llen(feishu_url))

    print(redis_client.lpop('xx21212'))

    #
    # print(redis_client.type(feishu))
    # _ = redis_client.lrange(feishu, 0, -1)
    # print(len(eval(_)))
